==> groovy2_2.4.5.orig.tar.xz: groovy-2.4.5/subprojects/groovy-groovydoc/src/main/java/org/codehaus/groovy/tools/groovydoc/ClasspathResourceManager.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.codehaus.groovy.tools.groovydoc;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import org.codehaus.groovy.runtime.IOGroovyMethods;

public class ClasspathResourceManager implements ResourceManager {
    ClassLoader classLoader;
    public ClasspathResourceManager() {
        classLoader = getClass().getClassLoader();
    }
    
    public ClasspathResourceManager(ClassLoader classLoader) {
        this.classLoader = classLoader;
    }

    public InputStream getInputStream(String resourceName) throws IOException {
        return classLoader.getResourceAsStream(resourceName);
    }

    public Reader getReader(String resourceName) throws IOException {
        return IOGroovyMethods.newReader(getInputStream(resourceName));
    }

}

==> groovy_2.4.8.orig.tar.xz: groovy-2.4.8/subprojects/groovy-groovydoc/src/main/java/org/codehaus/groovy/tools/groovydoc/ClasspathResourceManager.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.codehaus.groovy.tools.groovydoc;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import org.codehaus.groovy.runtime.IOGroovyMethods;

public class ClasspathResourceManager implements ResourceManager {
    ClassLoader classLoader;
    public ClasspathResourceManager() {
        classLoader = getClass().getClassLoader();
    }
    
    public ClasspathResourceManager(ClassLoader classLoader) {
        this.classLoader = classLoader;
    }

    public InputStream getInputStream(String resourceName) {
        return classLoader.getResourceAsStream(resourceName);
    }

    public Reader getReader(String resourceName) throws IOException {
        return IOGroovyMethods.newReader(getInputStream(resourceName));
    }

}
